@@ -41,17 +41,6 @@ CONFIG_TUGRAZ_ROUTES = {
 # ===========
 # See https://invenio-app.readthedocs.io/en/latest/configuration.html
 
-# TODO: move this to gitlab vars.
-APP_ALLOWED_HOSTS = [
-    "0.0.0.0",
-    "localhost",
-    "127.0.0.1",
-    "invenio-dev01.tugraz.at",
-    "invenio-test.tugraz.at",
-    "repository.tugraz.at",
-]
-"""Allowed Hosts"""
-
 APP_DEFAULT_SECURE_HEADERS = {
     "content_security_policy": {
         "default-src": [
@@ -325,3 +314,11 @@ reopened regularly.
 
 See https://docs.sqlalchemy.org/en/latest/core/engines.html.
 """
+
+# OAI-PMH
+# =======
+# See https://github.com/inveniosoftware/invenio-oaiserver/blob/master/invenio_oaiserver/config.py
+# TODO: move to gitlab
+
+OAISERVER_ID_PREFIX = "repository.tugraz.at"
+"""The prefix that will be applied to the generated OAI-PMH ids."""
