@@ -10,23 +10,24 @@
 
 from flask import Flask
 
-from invenio_config_tugraz import invenioconfigtugraz
+from invenio_config_tugraz import InvenioConfigTugraz
 
 
 def test_version():
     """Test version import."""
     from invenio_config_tugraz import __version__
+
     assert __version__
 
 
 def test_init():
     """Test extension initialization."""
-    app = Flask('testapp')
-    ext = invenioconfigtugraz(app)
-    assert 'invenio-config-tugraz' in app.extensions
+    app = Flask("testapp")
+    ext = InvenioConfigTugraz(app)
+    assert "invenio-config-tugraz" in app.extensions
 
-    app = Flask('testapp')
-    ext = invenioconfigtugraz()
-    assert 'invenio-config-tugraz' not in app.extensions
+    app = Flask("testapp")
+    ext = InvenioConfigTugraz()
+    assert "invenio-config-tugraz" not in app.extensions
     ext.init_app(app)
-    assert 'invenio-config-tugraz' in app.extensions
+    assert "invenio-config-tugraz" in app.extensions
